@@ -167,45 +167,47 @@ convert_na_to.data.frame <- function(x,
   )
 
   # list are not covered by .select_nse
-  if (length(select_nse) == 0) {
-    if (is.list(select)) {
-      if (inherits(exclude, "formula")) {
-        exclude <- all.vars(exclude)
-      }
+  if (length(select_nse) == 0 && is.list(select)) {
+    if (inherits(exclude, "formula")) {
+      exclude <- all.vars(exclude)
+    }
 
-      not_modify <- if (is.character(exclude)) {
-        exclude
-      } else if (is.numeric(exclude)) {
-        colnames(x)[exclude]
-      }
-      names_data <- names(x)
-      names_sel <- names(select)
-      apply_default <- names_data[which(!names_data %in% c(names_sel, not_modify))]
+    not_modify <- if (is.character(exclude)) {
+      exclude
+    } else if (is.numeric(exclude)) {
+      colnames(x)[exclude]
+    }
+    names_data <- names(x)
+    names_sel <- names(select)
+    apply_default <- names_data[which(!names_data %in% c(names_sel, not_modify))]
 
-      for (i in seq_along(names_sel)) {
-        if (!names_sel[i] %in% names_data) next
-        x[[names_sel[i]]] <- convert_na_to(
-          x[[names_sel[i]]],
-          replacement = select[[i]],
-          verbose = verbose
+    for (i in seq_along(names_sel)) {
+      if (!names_sel[i] %in% names_data) next
+      x[[names_sel[i]]] <- convert_na_to(
+        x[[names_sel[i]]],
+        replacement = select[[i]],
+        verbose = verbose
+      )
+    }
+
+    for (i in seq_along(apply_default)) {
+      to_convert <- x[[apply_default[i]]]
+      if (is.numeric(to_convert)) {
+        repl <- replace_num
+      } else if (is.character(to_convert)) {
+        repl <- replace_char
+      } else if (is.factor(to_convert)) {
+        repl <- replace_fac
+      }
+      if (!is.null(repl)) {
+        x[[apply_default[i]]] <- convert_na_to(
+          to_convert,
+          replacement = repl,
+          verbose = FALSE
         )
       }
-
-      for (i in seq_along(apply_default)) {
-        to_convert <- x[[apply_default[i]]]
-        if (is.numeric(to_convert)) {
-          repl <- replace_num
-        } else if (is.character(to_convert)) {
-          repl <- replace_char
-        } else if (is.factor(to_convert)) {
-          repl <- replace_fac
-        }
-        if (!is.null(repl)) {
-          x[[apply_default[i]]] <- convert_na_to(to_convert, replacement = repl, verbose = FALSE)
-        }
-      }
-      return(x)
     }
+    return(x)
   }
 
 
