@@ -7,7 +7,7 @@
 .process_std_center <- function(x,
                                 weights,
                                 robust,
-                                verbose,
+                                verbose = TRUE,
                                 reference = NULL,
                                 center = NULL,
                                 scale = NULL) {
@@ -31,14 +31,14 @@
 
 
   # Sanity checks
-  check <- .check_standardize_numeric(x, name = NULL, verbose = verbose, reference = reference)
+  check <- .check_standardize_numeric(x, name = NULL, verbose = verbose, reference = reference, center = center)
 
   if (is.factor(vals) || is.character(vals)) {
     vals <- .factor_to_numeric(vals)
   }
 
   # Get center and scale
-  ref <- .get_center_scale(vals, robust, weights, reference, .center = center, .scale = scale)
+  ref <- .get_center_scale(vals, robust, weights, reference, .center = center, .scale = scale, verbose = verbose)
 
   list(
     vals = vals,
@@ -193,7 +193,7 @@
 
 ## retrieve center and scale information ----
 
-.get_center_scale <- function(x, robust = FALSE, weights = NULL, reference = NULL, .center = NULL, .scale = NULL) {
+.get_center_scale <- function(x, robust = FALSE, weights = NULL, reference = NULL, .center = NULL, .scale = NULL, verbose = TRUE) {
   if (is.null(reference)) reference <- x
 
   # for center(), we have no scale. default to 0
@@ -210,14 +210,17 @@
   } else {
     center <- weighted_mean(reference, weights)
     scale <- weighted_sd(reference, weights)
+    if (is.na(scale)) scale <- 1
   }
 
   if (scale == 0) {
     scale <- 1
-    insight::format_warning(sprintf(
-      "%s is 0 - variable not standardized (only scaled).",
-      if (robust) "MAD" else "SD"
-    ))
+    if (verbose) {
+      insight::format_warning(sprintf(
+        "%s is 0 - variable not standardized (only scaled).",
+        if (robust) "MAD" else "SD"
+      ))
+    }
   }
 
   list(center = center, scale = scale)
@@ -231,9 +234,10 @@
 .check_standardize_numeric <- function(x,
                                        name = NULL,
                                        verbose = TRUE,
-                                       reference = NULL) {
+                                       reference = NULL,
+                                       center) {
   # Warning if only one value
-  if (insight::has_single_value(x) && is.null(reference)) {
+  if (insight::has_single_value(x) && is.null(reference) && is.null(center)) {
     if (verbose) {
       if (is.null(name)) {
         insight::format_alert(
